==> lhcsmapi-1.1.15.tar.gz: lhcsmapi-1.1.15/lhcsmapi/cals/CalsDbSignal.py <==
import pandas as pd
from datetime import datetime
from ..Time import Time
from ..dbsignal.DbSignal import DbSignal
import warnings

class CalsDbSignal(DbSignal):
    """CalsDbSignal class encapsulates parsing of a signal obtained from the CALS database with pytimber package."""


    def __init__(self, name={}, startTime=0, endTime=0, unit={}, ldb=None):
        super().__init__('CALS')
        self.Name = name
        self.StartTime = startTime
        self.EndTime = endTime
        self.Unit = unit
        self._ldb = ldb

        if self._ldb is None:
            raise Exception('You have to provide an instance of pytimber.LoggingDB via the ldb keyword')

    @staticmethod
    def getScaledSignalSeries(signalNames, startTime, endTime, ldb):
        signalDict = ldb.getScaled(signalNames, startTime, endTime, scaleAlgorithm='AVG', scaleInterval='MINUTE')
        signalDf = pd.DataFrame.from_dict(signalDict)
        return signalDf.loc[1, :]

    @staticmethod
    def buildSignal(**kwargs):
        """
            **Builds a PmSignal object**

            Method validates kwargs and returns a CalsSignal object.
            The method looks though kwargs for arguments to create a new CalsSignal. If arguments are not provided, default
            arguments are used

            :param kwargs: dictionary of (keyword: argument) pairs which parametrize an db API query
            :type kwargs: dictionary
            :return: initialized CalsDbSignal object

            - Example::

                from source.post_mortem.PmSignal import PmSignal
                system = "QPS"
                className = "DQAMCNMB_PMHSU"
                source = "B20L5"
                signalName = "I_HDS_4"
                eventTime = 1426220469491000000
                PmSignal().createSignal(system=system, className=className, source=source,
                              signalName=signalName, eventTime=eventTime)
               >>> <source.cals.CalsSignal.CalsSignal at 0x7f0256e74710>

            - Expected Fail Response::

                from source.cals.CalsSignal import CalsSignal
                arcCurrentName = "RPTE.UA47.RB.A45:I_MEAS"
                startTime = 1426220459491000000
                endTime =   1426220479491000000
                CalsSignal.buildSignal(name=arcCurrentName, startTime = startTime, endTime = endTime)
                >>> Exception: You have to provide a instance of pytimber.LoggingDB via the ldb keyword
        """

        # look through kwargs for constructor arguments
        name = CalsDbSignal.validateKeyInkwargs('name', str, tuple, **kwargs) or {}
        unit = CalsDbSignal.validateKeyInkwargs('unit', str, **kwargs) or {}

        startTime = CalsDbSignal.validateKeyInkwargs('startTime', int, pd.Timestamp, str, float, datetime, tuple, **kwargs) or 0
        endTime = CalsDbSignal.validateKeyInkwargs('endTime', int, pd.Timestamp, str, float, datetime, tuple, **kwargs)
        duration = CalsDbSignal.validateKeyInkwargs('duration', tuple, list, **kwargs)
        tz = CalsDbSignal.validateKeyInkwargs('tz', str, kwargs)

        # calculate start and end time based of parsed arguments
        startTime, endTime = Time.getQueryPeriodInUnixTime(startTime, endTime, duration, tz)

        # convert start and end to unix time in seconds with us precision for CALS api
        startTime = Time.convertToUnixTimeSeconds(startTime)
        endTime = Time.convertToUnixTimeSeconds(endTime)

        ldb_ = None # different syntax since the pytimber.LoggingDB can't be validated without being a dependency
        if 'ldb' in kwargs:
            ldb_ = kwargs['ldb']

        if isinstance(name, str):
            name = [name]
        return CalsDbSignal(name, startTime, endTime, unit, ldb_)

    def read(self, signal=None, **kwargs):
        """Method returns a pandas DataFrame containing all dbsignal  with an index formatted to ns"""
        return CalsDbSignal.getSignalDataframe(self.Name, self.StartTime, self.EndTime, self._ldb)

    @staticmethod
    def getSignalDataframe(names, startTime, endTime, ldb):
        """Method returns a pandas DataFrame with dbsignal"""
        signalDataframe = CalsDbSignal.getSignal(names[0], startTime, endTime, ldb)
        for s in range(1, len(names)):
            newFrame = CalsDbSignal.getSignal(names[s], startTime, endTime, ldb)
            signalDataframe = pd.concat([signalDataframe, newFrame], axis=1)
        return signalDataframe

    @staticmethod
    def getSignal(name, startTime, endTime, ldb):
        """
            **Returns a pandas DataFrame with one signalt**

            Method validates kwargs and returns a CalsSignal object.
            The method looks though kwargs for arguments to create a new CalsSignal.
            If arguments are not provided, default arguments are used.

            :param name: signal name to be queried
            :type name: string
            :param startTime: unix seconds representing the start time
            :param startTime: float
            :param endTime: unix seconds representing the end time
            :param endTime: float
            :return: pandas.dataframe with a single signal

            - Example::

                from source.cals.CalsSignal import CalsSignal
                import pytimber
                ldb = pytimber.LoggingDB()

                arcCurrentName = "RPTE.UA47.RB.A45:I_MEAS"
                startTime = 1426220459.4910002
                endTime =   1426220479.4910002
                I_MEAS = CalsSignal.getSignal(name=arcCurrentName, startTime = startTime,
                                       endTime = endTime, ldb = ldb)
                print(I_MEAS.head())
                >>>               RPTE.UA47.RB.A45:I_MEAS
                >>> 1.426220e+09                  10071.5
                >>> 1.426220e+09                  10076.5
                >>> 1.426220e+09                  10081.5
                >>> 1.426220e+09                  10086.5
                >>> 1.426220e+09                  10091.5

            - Expected Fail Response::

                from source.cals.CalsSignal import CalsSignal
                import pytimber
                ldb = pytimber.LoggingDB()
                arcCurrentName = "RPTE.UA47.RB.A45:I_MEA"
                startTime = 1426220459.4910002
                endTime =   1426220479.4910002
                I_MEAS = CalsSignal.getSignal(name=arcCurrentName, startTime = startTime,
                                       endTime = endTime, ldb = ldb)
                print(I_MEAS.head())
                >>> Empty DataFrame
                >>> Columns: []
                >>> Index: []
                >>> UserWarning: Querying CALS with the parameters name: RPTE.UA47.RB.A45:I_MEA, start time: 1426220459.4910002 and end time: 1426220479.4910002 returned no data.
                >>> An empty DataFrame was returned.
                >>> ___________________________________________________________________________________
                >>> Reproduce the error using the raw pytimber API:
                >>>
                >>> import pytimber
                >>> ldb = pytimber.LoggingDB()
                >>> ldb.get("RPTE.UA47.RB.A45:I_MEA", 1426220459.4910002, 1426220479.4910002)
        """
        try:
            d = ldb.get(name, startTime, endTime)
        except:
            exception = """Querying CALS with the parameters name: {0}, start time: {1} and end time: {2} failed
            ___________________________________________________________________________________
            Reproduce the error using the raw pytimber API:\n
            import pytimber
            ldb = pytimber.LoggingDB()
            ldb.get(\"{0}\", {1}, {2})""".format(name, startTime, endTime)

            raise Exception(exception)
        
        if d.get(name) is None:
            warning = """Querying CALS with the parameters name: {0}, start time: {1} and end time: {2} returned no data.
            An empty DataFrame is returned.
            ___________________________________________________________________________________
            Reproduce the error using the raw pytimber API:\n
            import pytimber
            ldb = pytimber.LoggingDB()
            ldb.get(\"{0}\", {1}, {2})""".format(name, startTime, endTime)

            warnings.warn(warning)
        
            return pd.DataFrame()

        return pd.DataFrame(d.get(name)[1], d.get(name)[0], [name])

==> lhcsmapi-1.1.123.tar.gz: lhcsmapi-1.1.123/lhcsmapi/cals/CalsDbSignal.py <==
import pandas as pd
from datetime import datetime
from ..Time import Time
from ..dbsignal.DbSignal import DbSignal
import warnings

class CalsDbSignal(DbSignal):
    """CalsDbSignal class encapsulates parsing of a signal obtained from the CALS database with pytimber package."""

    def __init__(self, name={}, startTime=0, endTime=0, unit={}, ldb=None):
        super().__init__('CALS')
        self.Name = name
        self.StartTime = startTime
        self.EndTime = endTime
        self.Unit = unit
        self._ldb = ldb

        if self._ldb is None:
            raise Exception('You have to provide an instance of pytimber.LoggingDB via the ldb keyword')

    def __str__(self):
        return "Db: CALS, Signal: {}, Start time = {}, End time = {}".format(self.Name[0], Time.convertToString(self.StartTime, 's'), Time.convertToString(self.EndTime, 's'))

    @staticmethod
    def getScaledSignalSeries(signalNames, startTime, endTime, ldb):
        signalDict = ldb.getScaled(signalNames, startTime, endTime, scaleAlgorithm='AVG', scaleInterval='MINUTE')
        signalDf = pd.DataFrame.from_dict(signalDict)
        return signalDf.loc[1, :]

    @staticmethod
    def buildSignal(**kwargs):
        """
            **Builds a PmSignal object**

            Method validates kwargs and returns a CalsSignal object.
            The method looks though kwargs for arguments to create a new CalsSignal. If arguments are not provided, default
            arguments are used

            :param kwargs: dictionary of (keyword: argument) pairs which parametrize an db API query
            :type kwargs: dictionary
            :return: initialized CalsDbSignal object

            - Example::

                from source.post_mortem.PmSignal import PmSignal
                system = "QPS"
                className = "DQAMCNMB_PMHSU"
                source = "B20L5"
                signalName = "I_HDS_4"
                eventTime = 1426220469491000000
                PmSignal().createSignal(system=system, className=className, source=source,
                              signalName=signalName, eventTime=eventTime)
               >>> <source.test_cals.CalsSignal.CalsSignal at 0x7f0256e74710>

            - Expected Fail Response::

                from source.test_cals.CalsSignal import CalsSignal
                arcCurrentName = "RPTE.UA47.RB.A45:I_MEAS"
                startTime = 1426220459491000000
                endTime =   1426220479491000000
                CalsSignal.buildSignal(name=arcCurrentName, startTime = startTime, endTime = endTime)
                >>> Exception: You have to provide a instance of pytimber.LoggingDB via the ldb keyword
        """

        # look through kwargs for constructor arguments
        name = CalsDbSignal.validateKeyInkwargs('name', str, tuple, **kwargs) or {}
        unit = CalsDbSignal.validateKeyInkwargs('unit', str, **kwargs) or {}

        startTime = CalsDbSignal.validateKeyInkwargs('startTime', int, pd.Timestamp, str, float, datetime, tuple, **kwargs) or 0
        endTime = CalsDbSignal.validateKeyInkwargs('endTime', int, pd.Timestamp, str, float, datetime, tuple, **kwargs)
        duration = CalsDbSignal.validateKeyInkwargs('duration', tuple, list, **kwargs)
        tz = CalsDbSignal.validateKeyInkwargs('tz', str, **kwargs)

        # calculate start and end time based of parsed arguments
        startTime, endTime = Time.getQueryPeriodInUnixTime(startTime, endTime, duration, tz)

        # convert start and end to unix time in seconds with us precision for CALS api
        startTime = Time.convertToUnixTimeSeconds(startTime, tz=tz)
        endTime = Time.convertToUnixTimeSeconds(endTime, tz=tz)

        ldb_ = None # different syntax since the pytimber.LoggingDB can't be validated without being a dependency
        if 'ldb' in kwargs:
            ldb_ = kwargs['ldb']

        if isinstance(name, str):
            name = [name]
        return CalsDbSignal(name, startTime, endTime, unit, ldb_)

    def read(self, signal=None, **kwargs):
        """Method returns a pandas DataFrame containing all dbsignal  with an index formatted to ns"""
        return CalsDbSignal.getSignalDataframe(self.Name, self.StartTime, self.EndTime, self._ldb)

    @staticmethod
    def getSignalDataframe(names, startTime, endTime, ldb):
        """Method returns a pandas DataFrame with dbsignal"""
        signalDataframe = CalsDbSignal.getSignal(names[0], startTime, endTime, ldb)
        for s in range(1, len(names)):
            newFrame = CalsDbSignal.getSignal(names[s], startTime, endTime, ldb)
            signalDataframe = pd.concat([signalDataframe, newFrame], axis=1)
        return signalDataframe

    @staticmethod
    def getSignal(name, startTime, endTime, ldb):
        """
            **Returns a pandas DataFrame with one signalt**

            Method validates kwargs and returns a CalsSignal object.
            The method looks though kwargs for arguments to create a new CalsSignal.
            If arguments are not provided, default arguments are used.

            :param name: signal name to be queried
            :type name: string
            :param startTime: unix seconds representing the start time
            :param startTime: float
            :param endTime: unix seconds representing the end time
            :param endTime: float
            :return: pandas.dataframe with a single signal

            - Example::

                from source.test_cals.CalsSignal import CalsSignal
                import pytimber
                ldb = pytimber.LoggingDB()

                arcCurrentName = "RPTE.UA47.RB.A45:I_MEAS"
                startTime = 1426220459.4910002
                endTime =   1426220479.4910002
                I_MEAS = CalsSignal.getSignal(name=arcCurrentName, startTime = startTime,
                                       endTime = endTime, ldb = ldb)
                print(I_MEAS.head())
                >>>               RPTE.UA47.RB.A45:I_MEAS
                >>> 1.426220e+09                  10071.5
                >>> 1.426220e+09                  10076.5
                >>> 1.426220e+09                  10081.5
                >>> 1.426220e+09                  10086.5
                >>> 1.426220e+09                  10091.5

            - Expected Fail Response::

                from source.test_cals.CalsSignal import CalsSignal
                import pytimber
                ldb = pytimber.LoggingDB()
                arcCurrentName = "RPTE.UA47.RB.A45:I_MEA"
                startTime = 1426220459.4910002
                endTime =   1426220479.4910002
                I_MEAS = CalsSignal.getSignal(name=arcCurrentName, startTime = startTime,
                                       endTime = endTime, ldb = ldb)
                print(I_MEAS.head())
                >>> Empty DataFrame
                >>> Columns: []
                >>> Index: []
                >>> UserWarning: Querying CALS with the parameters name: RPTE.UA47.RB.A45:I_MEA, start time: 1426220459.4910002 and end time: 1426220479.4910002 returned no data.
                >>> An empty DataFrame was returned.
                >>> ___________________________________________________________________________________
                >>> Reproduce the error using the raw pytimber API:
                >>>
                >>> import pytimber
                >>> ldb = pytimber.LoggingDB()
                >>> ldb.get("RPTE.UA47.RB.A45:I_MEA", 1426220459.4910002, 1426220479.4910002)
        """
        try:
            d = ldb.get(name, startTime, endTime)
        except:
            exception = """Querying CALS with the parameters name: {0}, start time: {1} and end time: {2} failed
            ___________________________________________________________________________________
            Reproduce the error using the raw pytimber API:\n
            import pytimber
            ldb = pytimber.LoggingDB()
            ldb.get(\"{0}\", {1}, {2})""".format(name, startTime, endTime)

            raise Exception(exception)
        
        if d.get(name) is None:
            warning = """Querying CALS with the parameters name: {0}, start time: {1} and end time: {2} returned no data.
            An empty DataFrame is returned.
            ___________________________________________________________________________________
            Reproduce the error using the raw pytimber API:\n
            import pytimber
            ldb = pytimber.LoggingDB()
            ldb.get(\"{0}\", {1}, {2})""".format(name, startTime, endTime)

            warnings.warn(warning)
        
            return pd.DataFrame()

        return pd.DataFrame(d.get(name)[1], d.get(name)[0], [name])
